using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Reflection;
using System.IO;


//Geospatial Platform (Map and MapGuide)
using OSGeo.MapGuide;

//Map Geospatial Platform
using Autodesk.Gis.Map.Platform;


//AutoCAD
using Autodesk.AutoCAD.Runtime;
using Autodesk.AutoCAD.EditorInput;
using Autodesk.AutoCAD.Geometry;


namespace GettingStarted
{
    public class Class1
    {

        string currentDir = null;
        Editor ed = Autodesk.AutoCAD.ApplicationServices.Application.DocumentManager.MdiActiveDocument.Editor;

        [CommandMethod("MapInfo")]
        public void MapInformation()
        {

            try
            {
                //Get the map object
                AcMapMap currentMap = AcMapMap.GetCurrentMap();
                string message = "";
                string mapName = "";

                //Get map name
                mapName = currentMap.Name;
                if (!string.IsNullOrEmpty(mapName))
                {
                    message += "MAP NAME: " + mapName + "\n";
                }

                //Get maplayers
                MgLayerCollection layers = currentMap.GetLayers();
                if (layers.Count > 0)
                {
                    message += "MAP LAYERS: \n";

                    foreach (AcMapLayer layer in layers)
                    {
                        message += layer.Name + "\n";
                    }
                }

                //Get coordinate system string in WKT
                string SRS = currentMap.GetMapSRS();
                if (!string.IsNullOrEmpty(SRS))
                {
                    message += "COORDINATE SYSTEM: " + SRS + "\n";
                }


                if (!string.IsNullOrEmpty(message))
                {
                    MessageBox.Show(message);
                }
            }
            catch(MgException ex)
            {
                MessageBox.Show("Error: " + ex.Message);

            }

        }

        [CommandMethod("GetAz")]
        public void GetAzimuth()
        {
            
            try
            {
                //Get map coordinate system. Reqd. for creating a coordinate system
                string SRS = AcMapMap.GetCurrentMap().GetMapSRS();

                PromptPointOptions opts = new PromptPointOptions("\nSelect first point ");
                Point3d point;
                PromptPointResult ptResult = ed.GetPoint(opts);
                if (ptResult.Status != PromptStatus.OK) return;               
                point = ptResult.Value;

                MgGeometryFactory geomFactory = new MgGeometryFactory();
                MgCoordinate coordStart = geomFactory.CreateCoordinateXY(point.X, point.Y);

                 opts = new PromptPointOptions("\nSelect second point ");
                 ptResult = ed.GetPoint(opts);
                if (ptResult.Status != PromptStatus.OK) return;
                point = ptResult.Value;

                //Create coordinates of clicked points
                MgCoordinate coordEnd = geomFactory.CreateCoordinateXY(point.X, point.Y);

                //Create a coordinate system factory object for creating coordinate systems
                MgCoordinateSystemFactory coordFactory = new MgCoordinateSystemFactory();
                //Create coordinate system object
                MgCoordinateSystem coordSys = coordFactory.Create(SRS);

                                //Get the coordinate system measure object for computing the azimuth
                MgCoordinateSystemMeasure measureCoordinate = coordSys.GetMeasure();

                double azimuthAngle = measureCoordinate.GetAzimuth(coordStart, coordEnd);
                ed.WriteMessage("\nAzimuth: " + azimuthAngle.ToString());
            }
            catch (MgException ex)
            {
                MessageBox.Show("Error: " + ex.Message);
            }

        }

        /// <summary>
        /// The path of the current assembly.
        /// </summary>
        string CurrentDir
        {
            get
            {
                if (string.IsNullOrEmpty(currentDir))
                {
                    Assembly asm = Assembly.GetExecutingAssembly();
                    FileInfo info = new FileInfo(asm.Location);
                    currentDir = info.DirectoryName;
                }

                return currentDir;
            }
        }

    }
}
